@@ -20,7 +20,7 @@ class SceneGraph(object):
 
     def __init__(self, base_frame='world'):
         """
-        Create a scene graph, holding homogenous transformation
+        Create a scene graph, holding homogeneous transformation
         matrices and instance information about geometry.
 
         Parameters
@@ -136,7 +136,7 @@ class SceneGraph(object):
             # parent -> child -> child
             path = self.transforms.shortest_path(
                 frame_from, frame_to)
-            # collect a homogenous transform for each edge
+            # collect a homogeneous transform for each edge
             matrices = [edge_data[(u, v)]['matrix'] for u, v in
                         zip(path[:-1], path[1:])]
             # multiply matrices into single transform
@@ -151,9 +151,8 @@ class SceneGraph(object):
         """
         Return the last time stamp data was modified.
         """
-        if hasattr(self, '_modified'):
-            return self._modified
-        return '0.0'
+        return (getattr(self, '_modified', '-') +
+                getattr(self.transforms, '_modified', '-'))
 
     def copy(self):
         """
@@ -520,6 +519,7 @@ class EnforcedForest(object):
         # topology has changed so clear cache
         if (u, v) not in self.edge_data:
             self._cache = {}
+            self._modified = str(uuid.uuid4())
         else:
             # check to see if matrix and geometry are identical
             edge = self.edge_data[(u, v)]
@@ -563,6 +563,7 @@ class EnforcedForest(object):
 
         # topology will change so clear cache
         self._cache = {}
+        self._modified = str(uuid.uuid4())
 
         # delete all children's references and parent reference
         children = [child for (child, parent) in self.parents.items() if parent == u]
@@ -583,7 +584,7 @@ class EnforcedForest(object):
 
     def shortest_path(self, u, v):
         """
-        Find the shortest path beween `u` and `v`.
+        Find the shortest path between `u` and `v`.
 
         Note that it will *always* be ordered from
         root direction to leaf direction, so `u` may
@@ -703,6 +704,12 @@ class EnforcedForest(object):
                 collected.update(childs)
         return collected
 
+    def modified(self):
+        """
+        Return the last time stamp data was modified.
+        """
+        return getattr(self, '_modified', '-')
+
 
 def kwargs_to_matrix(
         matrix=None,
@@ -713,12 +720,12 @@ def kwargs_to_matrix(
         **kwargs):
     """
     Take multiple keyword arguments and parse them
-    into a homogenous transformation matrix.
+    into a homogeneous transformation matrix.
 
     Returns
     ---------
     matrix : (4, 4) float
-      Homogenous transformation matrix.
+      Homogeneous transformation matrix.
     """
     if matrix is not None:
         # a matrix takes immediate precedence over other options
